package meerkat.voting.gui;

import com.google.protobuf.ByteString;
import javafx.application.Application;
import javafx.stage.Stage;
import meerkat.protobuf.BallotQuestionUIElementOuterClass;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.IOException;


/**
 * Created by Vladimir Eliezer Tokarev on 8/27/2016.
 * The current voting-booth intialization process is next:
 * Main calls to ChainBuilder which initilizes all the TwoWayNode's
 */
public class Main extends Application {

    /**
     * Converts the image from given path to bytes array
     * @param filepath the path to the wanted picture
     * @return byte array of the image
     * @throws IOException
     */
    private byte[] GetData(String filepath) throws IOException {
        byte[] imageInByte;
        BufferedImage originalImage = ImageIO.read(new File(filepath));

        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        ImageIO.write(originalImage, "png", baos);
        baos.flush();
        imageInByte = baos.toByteArray();
        baos.close();
        return imageInByte;
    }

    /**
     * Creates configuration for example
     * @return VotingBoothConfiguration object
     * @throws IOException
     */
    private VotingBoothConfiguration GetConfig() throws IOException {
       VotingBoothConfiguration config = new VotingBoothConfiguration();

        config.NameSelectionQuestion = BallotQuestionUIElementOuterClass.BallotQuestionUIElement.newBuilder()
                .setQuestion(BallotQuestionUIElementOuterClass.UIQuestion.newBuilder()
                        .setQuestionType(0)
                        .setQuestion(BallotQuestionUIElementOuterClass.Question.newBuilder()
                                .setQuestion(ByteString.copyFromUtf8("Who you vote for?"))))
                .setAnswers(BallotQuestionUIElementOuterClass.UIAnswers.newBuilder()
                        .setAnswersType(0)
                        .setAnswers(BallotQuestionUIElementOuterClass.ListOfAnswers.newBuilder()
                                .addAnswers(ByteString.copyFromUtf8("George Boosh"))
                                .addAnswers(ByteString.copyFromUtf8("Antonio Banderas"))
                                .addAnswers(ByteString.copyFromUtf8("Michal Jakson"))))
                .setRandomizeListOrder(true).build();

        config.NameSelectionByPictureQuestion = BallotQuestionUIElementOuterClass.BallotQuestionUIElement.newBuilder()
                .setQuestion(BallotQuestionUIElementOuterClass.UIQuestion.newBuilder()
                        .setQuestionType(0)
                        .setQuestion(BallotQuestionUIElementOuterClass.Question.newBuilder()
                                .setQuestion(ByteString.copyFromUtf8("Who you vote for?"))))
                .setAnswers(BallotQuestionUIElementOuterClass.UIAnswers.newBuilder()
                        .setAnswersType(2)
                        .setAnswers(BallotQuestionUIElementOuterClass.ListOfAnswers.newBuilder()
                                .addAnswers(ByteString.copyFrom(GetData("/F:/vova/meerkat/meerkat-java/voting-booth-gui/src/main/resources/images/GeorgeBush.png")))
                                .addAnswers(ByteString.copyFrom(GetData("/F:/vova/meerkat/meerkat-java/voting-booth-gui/src/main/resources/images/MichaelJackson.png")))
                                .addAnswers(ByteString.copyFrom(GetData("/F:/vova/meerkat/meerkat-java/voting-booth-gui/src/main/resources/images/AntonioBanderass.png")))))
                .setRandomizeListOrder(true).build();

       return config;
    }

    @Override
    public void start(Stage primaryStage) throws Exception
    {
        ChainBuilder.Build(primaryStage, GetConfig());
        primaryStage.setTitle("Meerkat Polling Station");
        primaryStage.show();
    }

    public static void main(String[] args) throws InterruptedException {
        launch(args);
    }

}

